@@ -1,4 +1,7 @@
 import asyncio
+import traceback
+import gc
+import os
 
 from time import time
 
@@ -9,48 +12,28 @@ class Slot(object):
 
     def __init__(self, start_requests, close_if_idle, scheduler, crawler):
         self.closing = None
-        self.inprogress = set()  # requests in progress
+        self.inprogress = set()
 
         self.start_requests = start_requests
-        self.doing_start_requests = False
         self.close_if_idle = close_if_idle
         self.scheduler = scheduler
         self.crawler = crawler
         self.heartbeat = None
         self.closing_wait = None
-        self.scrape = set()
-        self.closing_lock = None
 
     def add_request(self, request):
         self.inprogress.add(request)
 
-    def scrape_buffer_space(self, result, emit=None):
-        if isinstance(result, dict):
-            result = str(result)
-        if emit is None:
-            self.scrape.add(result)
-        else:
-            self.scrape.remove(result)
-
     def remove_request(self, request):
-        self.inprogress.remove(request)
-        self._maybe_fire_closing()
+        self.inprogress.discard(request)
 
     async def close(self):
-        self._maybe_fire_closing()
-        await self.crawler.di.get("tools").task_await(self, "closing_wait")
-
-    def _maybe_fire_closing(self):
-        if not self.inprogress:
-            if self.heartbeat:
-                self.heartbeat.cancel()
-            self.closing_wait = True
+        self.closing = True
 
 
 class ExecutionEngine(object):
 
     def __init__(self, crawler, spider_closed_callback):
-        self.lock = True
         self.start_time = time()
         self.crawler = crawler
         self.settings = crawler.settings
@@ -58,12 +41,15 @@ class ExecutionEngine(object):
         self.spider = None
         self.scheduler = None
         self.running = False
+        self._heart_beat = None
+        self._task_beat = None
         self.signals = crawler.signals
         self.logformatter = crawler.load("log_formatter")
         self.scheduler = crawler.load("scheduler")
-        self.downloader = crawler.load("downloader")
-        self.scraper = call_grace_instance("scraper", crawler, self)
+        self.downloader = call_grace_instance('downloader', crawler)
+        self.scraper = call_grace_instance("scraper", crawler)
         self.call_helper = self.di.get("tools").call_helper
+        self.lock = asyncio.Lock()
         self._spider_closed_callback = spider_closed_callback
 
     async def start(self, spider, start_requests=None):
@@ -74,58 +60,28 @@ class ExecutionEngine(object):
 
     async def stop(self):
         self.running = False
-        await self._close_all_spiders()
+        # await self._close_all_spiders()
         await self.signals.send_catch_log_coroutine(signal=signals.engine_stopped)
 
-    async def close(self):
-
-        if self.running:
-            await self.stop()
-        elif self.open_spiders:
-            await self._close_all_spiders()
-        else:
-            self.downloader.close()
-
-    async def _next_request(self, spider):
-        slot = self.slot
-        if not slot:
-            return
-
-        while self.lock and not self._needs_backout(spider) and self.lock:
-            self.lock = False
+    async def start_spider_request(self, spider):
+        if self.slot.start_requests and not self._needs_backout():
             try:
-                if not await self.call_helper(slot.scheduler.has_pending_requests):
-                    break
-                request = await self.call_helper(slot.scheduler.next_request)
-                slot.add_request(request)
-                await self.downloader.fetch(request, spider, self._handle_downloader_output)
-            finally:
-                self.lock = True
-
-        if slot.start_requests and not self._needs_backout(spider) and not slot.doing_start_requests:
-            slot.doing_start_requests = True
-            try:
-                request = await slot.start_requests.__anext__()
+                request = await self.slot.start_requests.__anext__()
             except StopAsyncIteration:
-                slot.start_requests = None
+                self.slot.start_requests = None
             except Exception:
-                slot.start_requests = None
+                self.slot.start_requests = None
                 self.logger.error('Error while obtaining start requests',
-                             exc_info=True, extra={'spider': spider})
+                                    exc_info=True, extra={'spider': spider})
             else:
                 await self.crawl(request, spider)
-            finally:
-                slot.doing_start_requests = False
 
-        if self.running and await self.spider_is_idle(spider) and slot.close_if_idle:
-            await self._spider_idle(spider)
-
-    def _needs_backout(self, spider):
+    def _needs_backout(self) -> bool:
         return (
-                not self.running
-                or self.slot.closing
-                or self.downloader.needs_backout()
-                or self.scraper.slot.needs_backout()
+            not self.running
+            or self.slot.closing
+            or self.downloader.needs_backout()
+            or self.scraper.slot.needs_backout()
         )
 
     async def _handle_downloader_output(self, result, request, spider):
@@ -141,10 +97,11 @@ class ExecutionEngine(object):
                     self.logger.log(level, message, **kwargs)
                 await self.signals.send_catch_log(signals.response_received,
                                                   response=result, request=request, spider=spider)
+        except Exception as e:
+            self.logger.error(f"enqueue_scrape: {traceback.format_exc()}")
         finally:
             self.slot.remove_request(request)
-            asyncio.create_task(self._next_request(self.spider))
-        await self.scraper.enqueue_scrape(result, request, spider)
+        await self.scraper.enqueue_scrape(result, request)
 
     async def spider_is_idle(self, spider):
         if self.scraper.slot.is_idle():
@@ -192,15 +149,17 @@ class ExecutionEngine(object):
         self.slot = Slot(start_requests, close_if_idle, self.scheduler, self.crawler)
         self.spider = spider
         await self.call_helper(self.scheduler.open, start_requests)
+        await self.call_helper(self.downloader.open, spider, self)
         await self.call_helper(self.scraper.open_spider, spider)
         await self.call_helper(self.crawler.stats.open_spider, spider)
         await self.signals.send_catch_log_coroutine(signals.spider_opened, spider=spider)
-        await self._next_request(spider)
+        await self.start_spider_request(spider)
         if self.slot is None:
             self.logger.warning("Spider ({name}) to running not found task! please check task is be generated.",
                                 **{"name": spider.name})
             return
-        self.slot.heartbeat = asyncio.create_task(self.heart_beat(0.2, spider, self.slot))
+        self._heart_beat = asyncio.create_task(self.heart_beat(5, spider, self.slot))
+        self._task_beat = asyncio.create_task(self.task_beat())
 
     async def _close_all_spiders(self):
         dfds = [self.close_spider(s, reason='shutdown') for s in self.open_spiders]
@@ -209,14 +168,12 @@ class ExecutionEngine(object):
     async def close_spider(self, spider, reason='cancelled'):
         """Close (cancel) spider and clear all its outstanding requests"""
         slot = self.slot
-        if slot and slot.closing or slot.closing_lock:
+        if slot.closing:
             return slot.closing
 
-        slot.closing_lock = True
-
         self.logger.info("Closing spider({name}) ({reason})",
-                    **{'reason': reason, 'name': spider.name},
-                    extra={'spider': spider})
+                         **{'reason': reason, 'name': spider.name},
+                         extra={'spider': spider})
 
         await slot.close()
 
@@ -243,13 +200,14 @@ class ExecutionEngine(object):
 
         await close_handler(self.crawler.stats.close_spider, spider, reason=reason, errmsg='Stats close failure')
 
-        self.logger.info("Spider({name}) closed ({reason})", **{'reason': reason, "name": spider.name}, extra={'spider': spider})
-
-        await close_handler(setattr, self, 'slot', None, errmsg='Error while unassigning slot')
-
-        await close_handler(setattr, self, 'spider', None, errmsg='Error while unassigning spider')
+        self.logger.info("Spider({name}) closed ({reason})", **
+                         {'reason': reason, "name": spider.name}, extra={'spider': spider})
 
         await self._spider_closed_callback()
+        if self._heart_beat:
+            self._heart_beat.cancel()
+        if self._task_beat:
+            self._task_beat.cancel()
 
     async def _spider_idle(self, spider):
         res = await self.signals.send_catch_log(signals.spider_idle, spider=spider, dont_log=self.di.get("exceptions").DontCloseSpider)
@@ -259,6 +217,34 @@ class ExecutionEngine(object):
             await self.close_spider(spider, reason='finished')
 
     async def heart_beat(self, delay, spider, slot):
-        while not slot.closing:
+        while True:
             await asyncio.sleep(delay)
-            asyncio.create_task(self._next_request(spider))
+            if self.running and await self.spider_is_idle(spider) and slot.close_if_idle:
+                await self._spider_idle(spider)
+            co = '<logstats: %(spname)s> pid: %(pid)s, transferring: %(transfer)s, queue: %(queue)s, active: %(active)s, ingress: %(ingress)s, scraper-active: %(sactive)s, scraper-queue: %(squeue)s, scraper-size: %(size)s' % {
+                'spname': spider.name,
+                'pid': os.getpid(),
+                'transfer': len(self.downloader.slot.transferring),
+                'queue': len(self.downloader.slot.queue),
+                'active': len(self.downloader.active),
+                'ingress': len(self.slot.inprogress),
+                'sactive': len(self.scraper.slot.active),
+                'squeue': len(self.scraper.slot.queue),
+                'size': self.scraper.slot.active_size,
+            }
+            self.logger.debug(co)
+            try:
+                gc.collect()
+            except:
+                self.logger.warning(f'gc collect faild!')
+
+    async def task_beat(self):
+        local_lock = True
+        while True:
+            while local_lock and not self._needs_backout():
+                local_lock = False
+                for request in await self.slot.scheduler.async_next_request():
+                    self.slot.add_request(request)
+                    await self.downloader.fetch(request)
+                local_lock = True
+            await asyncio.sleep(1)
