@@ -1,6 +1,10 @@
 import pprint
 import asyncio
+import anyio
 import signal
+import traceback
+
+from typing import Optional, Type, Union, Any
 
 from aioscpy.settings import overridden_settings
 from aioscpy.settings import Settings
@@ -8,11 +12,12 @@ from aioscpy.signalmanager import SignalManager
 from aioscpy.utils.ossignal import install_shutdown_handlers, signal_names
 from aioscpy.inject import DependencyInjection
 from aioscpy import call_grace_instance
+from aioscpy.spider import Spider
 
 
 class Crawler(object):
 
-    def __init__(self, spidercls, *args, settings=None, **kwargs):
+    def __init__(self, spidercls: Type[Spider], settings: Union[Settings, dict, None] = None, * args, ** kwargs):
 
         if isinstance(settings, dict) or settings is None:
             settings = Settings(settings)
@@ -35,7 +40,7 @@ class Crawler(object):
         self.extensions = self.load('extension')
         self._close_wait = None
 
-    async def crawl(self):
+    async def crawl(self) -> None:
         if self.crawling:
             raise RuntimeError("Crawling already taking place")
         self.crawling = True
@@ -49,13 +54,13 @@ class Crawler(object):
             await self.engine.start(self.spider, start_requests)
             await self.di.get("tools").task_await(self, "_close_wait")
         except Exception as e:
-            self.logger.exception(e)
+            self.logger.error(f"crawler: {traceback.format_exc()}")
             self.crawling = False
             if self.engine is not None:
                 await self.engine.close()
             raise e
 
-    def load(self, key):
+    def load(self, key: str) -> Any:
         return self.DI.load(key)
 
     def _create_spider(self, *args, **kwargs):
@@ -80,7 +85,7 @@ class CrawlerProcess(object):
         doc="Set of :class:`crawlers <aioscpy.crawler.Crawler>`"
     )
 
-    def __init__(self, settings=None, install_root_handler=True):
+    def __init__(self, settings: Union[Settings, dict, None] = None):
         if isinstance(settings, dict) or settings is None:
             settings = Settings(settings)
         self.settings = settings
@@ -91,16 +96,16 @@ class CrawlerProcess(object):
         install_shutdown_handlers(self._signal_shutdown)
         self.di.get("log").std_log_aioscpy_info(settings)
 
-    def crawl(self, crawler_or_spidercls, *args, **kwargs):
+    def crawl(self, crawler_or_spidercls: Union[Type[Spider], Crawler], *args, **kwargs) -> Crawler:
         crawler = self.create_crawler(crawler_or_spidercls, *args, **kwargs)
         self.crawlers.add(crawler)
         return crawler
 
-    def crawl_soon(self, crawler_or_spidercls, *args, **kwargs):
+    def crawl_soon(self, crawler_or_spidercls: Union[Type[Spider], Crawler], *args, **kwargs):
         crawler = self.crawl(crawler_or_spidercls, *args, **kwargs)
         self.active_crawler(crawler)
 
-    def create_crawler(self, crawler_or_spidercls, *args, **kwargs):
+    def create_crawler(self, crawler_or_spidercls: Union[Type[Spider], Crawler], *args, **kwargs) -> Crawler:
         if isinstance(crawler_or_spidercls, Crawler):
             return crawler_or_spidercls
         if isinstance(crawler_or_spidercls, str):
@@ -108,7 +113,7 @@ class CrawlerProcess(object):
         settings = kwargs.pop('settings', self.settings)
         return call_grace_instance("crawler", crawler_or_spidercls, *args, settings=settings, **kwargs)
 
-    def active_crawler(self, crawler):
+    def active_crawler(self, crawler: Crawler):
         task = asyncio.create_task(crawler.crawl())
         self._active.add(task)
 
@@ -120,7 +125,7 @@ class CrawlerProcess(object):
 
         task.add_done_callback(_done)
 
-    def load_spider(self, path=None, spider_key: str = None):
+    def load_spider(self, path: str = None, spider_key: str = None, spider_like: str = ""):
         if path is None:
             path = ''.join(['./', self.settings.get("NEWSPIDER_MODULE", "spiders")])
         spiders_cls = DependencyInjection.load_all_spider(path)
@@ -131,8 +136,11 @@ class CrawlerProcess(object):
             else:
                 raise KeyError(f"Spider not found: {spider_key}")
         for name, spider_cls in spiders_cls.items():
+            if spider_like and not spider_like in name:
+                continue
             self.crawl(spider_cls)
-            self.logger.debug("Loading spider({name}) from {path}", **{"name": name, "path": path})
+            self.logger.debug(
+                "Loading spider({name}) from {path}", **{"name": name, "path": path})
 
     async def stop(self):
         return await asyncio.gather(*[c.stop() for c in list(self.crawlers)])
@@ -144,9 +152,6 @@ class CrawlerProcess(object):
             self._group.append(await asyncio.gather(*self._active, return_exceptions=True))
 
     async def _graceful_stop_reactor(self):
-        await self.stop()
-
-    async def _force_stop_reactor(self):
         for task in self._active:
             task.cancel()
         for group in self._group:
@@ -155,6 +160,9 @@ class CrawlerProcess(object):
         for ct in current_task:
             ct.cancel()
         await asyncio.sleep(1)
+        await self.stop()
+
+    async def _force_stop_reactor(self):
         asyncio.get_running_loop().stop()
 
     def _signal_shutdown(self, signum, _):
@@ -173,7 +181,9 @@ class CrawlerProcess(object):
 
     def start(self):
         self.di.get("tools").install_event_loop_tips()
+        self.di.get("tools").install_patch_method()
         try:
-            asyncio.run(self.run())
+            anyio.run(self.run, backend='asyncio')
+            # asyncio.run(self.run())
         except asyncio.CancelledError:
             pass
