@@ -1,5 +1,6 @@
 from aioscpy.http.request import Request
 from aioscpy.http.request.form import FormRequest
+from aioscpy.http.request.json import JsonRequest
 
 from aioscpy.http.response import Response
 from aioscpy.http.response.text import TextResponse
@@ -8,6 +9,7 @@ from aioscpy.http.response.text import TextResponse
 __all__ = [
     Request,
     FormRequest,
+    JsonRequest,
     Response,
     TextResponse
 ]
