@@ -70,7 +70,7 @@ class DependencyInjection(object):
     def from_crawler(cls, crawler):
         return cls.from_settings(crawler.settings, crawler)
 
-    def load(self, key):
+    def load(self, key: str):
         return self.slot.get(key)
 
     @staticmethod
@@ -159,7 +159,7 @@ class DependencyInjection(object):
             raise KeyError('Settings DI_CONFIG/DI_CONFIG_CLS not be None')
         for key, value in self.settings['DI_CONFIG'].items():
             self.load_object_slot(key, value)
-        self.slot.live_beat = asyncio.create_task(self.live_beat())
+        # self.slot.live_beat = asyncio.create_task(self.live_beat())
 
     async def live_beat(self):
         while 1:
