@@ -13,6 +13,7 @@ DOWNLOAD_TIMEOUT = 20
 DOWNLOAD_HANDLER = "aioscpy.core.downloader.handlers.httpx.HttpxDownloadHandler"
 # SCHEDULER = "aioscpy.core.scheduler.redis.RedisScheduler"
 SCHEDULER = "aioscpy.core.scheduler.memory.MemoryScheduler"
+REQUESTS_SESSION_STATS = False
 
 
 SPIDER_IDLE = False
@@ -27,9 +28,6 @@ LOG_RETENTION = "30 days"
 
 DI_CONFIG = {
     "scheduler": f"{SCHEDULER}",
-    'downloader_middleware': 'aioscpy.middleware.DownloaderMiddlewareManager',
-    "downloader": "aioscpy.core.downloader.Downloader",
-    "item_processor": "aioscpy.middleware.ItemPipelineManager",
     "log_formatter": "aioscpy.logformatter.LogFormatter",
     "extension": "aioscpy.middleware.ExtensionManager",
 
@@ -38,10 +36,13 @@ DI_CONFIG_CLS = {
     "request": "aioscpy.http.Request",
     "response": "aioscpy.http.TextResponse",
     "form_request": "aioscpy.http.FormRequest",
+    "json_request": "aioscpy.http.JsonRequest",
     "logger": "aioscpy.utils.log.logger",
     "log": "aioscpy.utils.log",
     "exceptions": "aioscpy.exceptions",
     "tools": "aioscpy.utils.tools",
+    'downloader_middleware': 'aioscpy.middleware.DownloaderMiddlewareManager',
+    "item_processor": "aioscpy.middleware.ItemPipelineManager",
 }
 DI_CREATE_CLS = {
     'crawler': 'aioscpy.crawler.Crawler',
@@ -50,7 +51,8 @@ DI_CREATE_CLS = {
     'spider': 'aioscpy.spider.Spider',
     'downloader_handler': f'{DOWNLOAD_HANDLER}',
     'stats': 'aioscpy.libs.statscollectors.MemoryStatsCollector',
-    'scraper': 'aioscpy.core.scraper.Scraper'
+    'scraper': 'aioscpy.core.scraper.Scraper',
+    "downloader": "aioscpy.core.downloader.Downloader",
 }
 
 # message config
