@@ -1,3 +1,5 @@
+import ujson
+import json
 import asyncio
 import weakref
 import sys
@@ -272,7 +274,6 @@ def get_project_settings():
     settings.setdict(aioscpy_envvars, priority='project')
     settings['DI_CONFIG']['scheduler'] = settings['SCHEDULER']
     settings['DI_CREATE_CLS']['downloader_handler'] = settings['DOWNLOAD_HANDLER']
-    settings['LOG_FILENAME'] = f"{settings['BOT_NAME']}.log"
     return settings
 
 
@@ -321,3 +322,13 @@ def obsolete_setter(setter, attrname):
         msg = "%s.%s is not modifiable, use %s.replace() instead" % (c, attrname, c)
         raise AttributeError(msg)
     return newsetter
+
+
+def monkey_patch_json():
+    json.__name__ = 'ujson'
+    json.dumps = ujson.dumps
+    json.loads = ujson.loads
+
+
+def install_patch_method():
+    monkey_patch_json()
